## Summary

Brief description of what this PR does.

## Related Issues

Closes #(issue number)

## Changes

- [ ] Change 1
- [ ] Change 2

## Type of Change

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] New shape (adds a new data collection shape)
- [ ] Breaking change (fix or feature that would cause existing functionality to change)
- [ ] Documentation update

## Checklist

- [ ] Tests pass (`pytest`)
- [ ] Linter passes (`ruff check src/ tests/`)
- [ ] Type checker passes (`mypy src/`)
- [ ] I've added tests for new functionality
- [ ] I've updated documentation if needed
- [ ] I've updated CHANGELOG.md (under `[Unreleased]`)
